<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <location filename="language.h" line="31"/>
        <source>Afar</source>
        <translation>ཨ་ཧྥེར་གྱི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="32"/>
        <source>Afrikaans</source>
        <translation>ཨ་ཧྥེ་རི་ཁ་ལྷོ་མའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="33"/>
        <source>አማርኛ</source>
        <translation>ཨ་མུ་ཧ་ལའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="34"/>
        <source>عربية</source>
        <translation>ཨ་རབ་ཀྱི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="35"/>
        <source>অসমীয়া</source>
        <translation>ཨ་ས་མུའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="36"/>
        <source>Asturianu</source>
        <translation>ཨོ་སི་ཐུ་ལི་ཡ་སིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="37"/>
        <source>Беларуская</source>
        <translation>ཨུ་རུ་སུ་དཀར་པོའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="38"/>
        <source>Biełaruskaja łacinka</source>
        <translation>ཨུ་རུ་སུ་དཀར་པོའི་ལ་ཏིང་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="39"/>
        <source>Български</source>
        <translation>པུར་ཀ་རི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="40"/>
        <source>বাংলা</source>
        <translation>བྷང་ག་ལའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="41"/>
        <source>বাংলা (ভারত)</source>
        <translation>བྷང་ག་ལའི་སྐད།（རྒྱ་གར།）</translation>
    </message>
    <message>
        <location filename="language.h" line="42"/>
        <source>བོད་སྐད།</source>
        <translation>བོད་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="43"/>
        <source>Brezhoneg</source>
        <translation>པུ་ལེ་ཐ་ཉིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="44"/>
        <source>Bosanski</source>
        <translation>སྦོ་སི་ནེའི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="45"/>
        <source>Català</source>
        <translation>ཀ་ཏ་ལའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="46"/>
        <source>Qırımtatarca</source>
        <translation>ཁ་རི་མེ་ཨ་ཐུར་ཆིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="47"/>
        <source>Český</source>
        <translation>ཅེ་ཁའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="48"/>
        <source>Kaszëbsczi</source>
        <translation>ཁ་ཧྲུའུ་པིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="49"/>
        <source>Чăвашла</source>
        <translation>ཁྲུའུ་ཝ་ཧྲེན་གྱི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="50"/>
        <source>Cymraeg</source>
        <translation>ཝེར་ཧྲིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="51"/>
        <source>Dansk</source>
        <translation>ཏེན་མག་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="52"/>
        <source>Deutsch</source>
        <translation>འཇར་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="53"/>
        <source>ཇོང་ཁ</source>
        <translation>འབྲུག་ཡུལ་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="54"/>
        <source>Ελληνικά</source>
        <translation>ཀེ་རི་སེའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="55"/>
        <source>British English</source>
        <translation>དབྱིན་ཇིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="56"/>
        <source>American English</source>
        <translation>ཨ་རིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="57"/>
        <source>Español</source>
        <translation>སི་ཕེན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="58"/>
        <source>Eesti</source>
        <translation>ཨེ་སོ་ནི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="59"/>
        <source>Euskara</source>
        <translation>པ་སི་ཁེའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="60"/>
        <source>فارسی</source>
        <translation>ཏ་ཟིག་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="61"/>
        <source>Suomi</source>
        <translation>ཧྥིན་ལན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="62"/>
        <source>Føroyskt</source>
        <translation>ཧྥ་རོའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="63"/>
        <source>Français</source>
        <translation>ཧྥ་རན་སེའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="64"/>
        <source>Frysk</source>
        <translation>ཞི་ཧྥུ་ལི་སི་ལན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="65"/>
        <source>Gaeilge</source>
        <translation>ཨིར་ལན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="66"/>
        <source>Gàidhlig</source>
        <translation>ཀེར་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="67"/>
        <source>Galego</source>
        <translation>ཀ་ལི་ནི་ཞི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="68"/>
        <source>ગુજરાતી </source>
        <translation>ཀུ་ཅི་ལ་ཐེའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="69"/>
        <source>Gaelg</source>
        <translation>མན་ཏའོ་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="70"/>
        <source>هَوُسَ</source>
        <translation>ཧའོ་སའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="71"/>
        <source>עברית</source>
        <translation>སི་པོ་ལའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="72"/>
        <source>हिन्दी</source>
        <translation>ཧིན་རྡིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="73"/>
        <source>Chhattisgarhi</source>
        <translation>ཆ་ཏི་སི་ཆར་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="74"/>
        <source>Hrvatski</source>
        <translation>ཁོ་ལུའོ་ཏི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="75"/>
        <source>Hornjoserbsce</source>
        <translation>ཧྲང་སུའོ་པུའུ་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="76"/>
        <source>Magyar</source>
        <translation>ཧང་ག་རིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="77"/>
        <source>Հայերեն</source>
        <translation>ཡ་མེ་ཉེ་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="78"/>
        <source>Indonesia</source>
        <translation>ཧིན་རྡི་ཉི་ཞི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="79"/>
        <source>Iñupiak</source>
        <translation>དབྱི་ནུའུ་ཕི་ཁེའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="80"/>
        <source>Íslenska</source>
        <translation>འཁྱགས་གླིང་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="81"/>
        <source>Italiano</source>
        <translation>དབྱི་ཐ་ལིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="82"/>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation>དབྱིན་ཉུའུ་ཐེའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="83"/>
        <source>日本語</source>
        <translation>ཉི་ཧོང་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="84"/>
        <source>ქართული</source>
        <translation>ཀུ་ལུའུ་ཅེ་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="85"/>
        <source>Қазақша</source>
        <translation>ཧ་སག་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="86"/>
        <source>Kalaallisut</source>
        <translation>ཀེ་ལིན་ལན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="87"/>
        <source>ខ្មែរ</source>
        <translation>ཀའོ་མན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="88"/>
        <source>ಕನ್ನಡ</source>
        <translation>ཁ་ན་ཏའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="89"/>
        <source>한국어</source>
        <translation>ཁོ་རེ་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="90"/>
        <source>कश्मीरी - (كشميري)</source>
        <translation>ཁ་ཆེའི་སྐད། - (كشميري)</translation>
    </message>
    <message>
        <location filename="language.h" line="91"/>
        <source>Kurdî</source>
        <translation>ཁུ་ཏེར་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="92"/>
        <source>Kernewek</source>
        <translation>ཁང་འོར་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="93"/>
        <source>Кыргызча</source>
        <translation>ཅིར་ཅི་སེའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="94"/>
        <source>Lëtzebuergesch</source>
        <translation>ལུ་ཙེམ་པོག་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="95"/>
        <source>Limburgs</source>
        <translation>ལིན་པའོ་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="96"/>
        <source>ລາວ</source>
        <translation>ལོ་སིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="97"/>
        <source>Lietuvių</source>
        <translation>ལི་ཐུ་ཝན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="98"/>
        <source>Latviešu</source>
        <translation>ལ་ཐེ་ཝེ་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="99"/>
        <source>Maithili</source>
        <translation>མའེ་ཏི་ལིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="100"/>
        <source>Malagasy</source>
        <translation>མ་ཏ་ཀ་སི་ཁར་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="101"/>
        <source>Ebon</source>
        <translation>ཚའོ་ཡོན་མ་ལིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="102"/>
        <source>Māori</source>
        <translation>མའོ་ལིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="103"/>
        <source>Македонски</source>
        <translation>མ་ཆི་ཏུན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="104"/>
        <source>മലയാളം</source>
        <translation>མ་ལ་ཡ་ལ་མུའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="105"/>
        <source>Монгол</source>
        <translation>སོག་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="106"/>
        <source>मराठी</source>
        <translation>མ་ལ་ཏིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="107"/>
        <source>Bahasa Melayu</source>
        <translation>མ་ལེའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="108"/>
        <source>Malti</source>
        <translation>མར་ཐའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="109"/>
        <source>Myanmasa</source>
        <translation>འབར་མའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="110"/>
        <source>Ekakairũ Naoero</source>
        <translation>རྨིན་ནན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="111"/>
        <source>Norsk (bokmål)</source>
        <translation>ནོར་ཝེའི་སྐད།（པུ་ཁེ་མོར་སྐད།）</translation>
    </message>
    <message>
        <location filename="language.h" line="112"/>
        <source>Plattdüütsch</source>
        <translation>འཇར་མན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="113"/>
        <source>नेपाली</source>
        <translation>བལ་ཡུལ་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="114"/>
        <source>Nederlands</source>
        <translation>ཧོ་ལན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="115"/>
        <source>Norsk (nynorsk)</source>
        <translation>ནོར་ཝེའི་སྐད།（ནོར་ཝེ་གསར་མའི་སྐད།）</translation>
    </message>
    <message>
        <location filename="language.h" line="116"/>
        <source>IsiNdebele</source>
        <translation>ནན་ཨེན་ཏེ་པེ་ལའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="117"/>
        <source>Sesotho sa Leboa</source>
        <translation>པེ་སོ་ནིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="118"/>
        <source>Occitan</source>
        <translation>ཨོ་ཁེའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="119"/>
        <source>Oromoo</source>
        <translation>ཨོ་རོ་མུའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="120"/>
        <source>ଓଡ଼ିଆ</source>
        <translation>ཨོ་ལི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="121"/>
        <source>Иронау</source>
        <translation>ཨའོ་སའེ་ཐིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="122"/>
        <source>ਪੰਜਾਬੀ</source>
        <translation>ལེགས་སྦྱར་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="123"/>
        <source>Polski</source>
        <translation>པོ་ལན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="124"/>
        <source>پښتو</source>
        <translation>ཕུ་ཧྲེན་ཐུའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="125"/>
        <source>Português</source>
        <translation>ཕོར་ཐིའུ་ཀེལ་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="126"/>
        <source>Português do Brasil</source>
        <translation>ཕོར་ཐིའུ་ཀེལ་སྐད། པ་ཞི།Português do Brasil</translation>
    </message>
    <message>
        <location filename="language.h" line="127"/>
        <source>Română</source>
        <translation>རོ་མ་ནི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="128"/>
        <source>Русский</source>
        <translation>ཨུ་རུ་སུའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="129"/>
        <source>Kinyarwanda</source>
        <translation>རུ་ཝང་ཏའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="130"/>
        <source>संस्कृत</source>
        <translation>ལེགས་སྦྱར་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="131"/>
        <source>Sardu</source>
        <translation>ས་ཏིང་ནི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="132"/>
        <source>سنڌي</source>
        <translation>ཞིན་ཏེའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="133"/>
        <source>Sámegiella</source>
        <translation>ས་སྨི་བྱང་མའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="134"/>
        <source>සිංහල</source>
        <translation>སིང་གྷ་གླིང་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="135"/>
        <source>Slovenčina</source>
        <translation>སི་ལོ་ཝ་ཁེའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="136"/>
        <source>Slovenščina</source>
        <translation>སི་ལོ་ཝུན་ཉི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="137"/>
        <source>Soomaaliga</source>
        <translation>སོ་མ་ལིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="138"/>
        <source>Shqip</source>
        <translation>ཨར་པ་ནི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="139"/>
        <source>Српски</source>
        <translation>སར་ཝེ་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="140"/>
        <source>srpski (latinica)</source>
        <translation>སར་ཝེ་ཡའི་སྐད།（ལ་ཏིང་།）</translation>
    </message>
    <message>
        <location filename="language.h" line="141"/>
        <source>SiSwati</source>
        <translation>ས་ཝ་ཏིའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="142"/>
        <source>Sesotho</source>
        <translation>སོ་ཐོ་ལྷོ་མའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="143"/>
        <source>Svenska</source>
        <translation>སུའེ་ཏེན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="144"/>
        <source>Swahili</source>
        <translation>སི་ཝ་ཞི་ལི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="145"/>
        <source>தமிழ்</source>
        <translation>ཐའེ་སྨིར་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="146"/>
        <source>తెలుగు</source>
        <translation>ཐའེ་ལུའུ་ཀུའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="147"/>
        <source>Тоҷикӣ</source>
        <translation>ཐ་ཅི་ཁེའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="148"/>
        <source>ภาษาไทย</source>
        <translation>ཐེན་ལན་ཀྲེའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="149"/>
        <source>ትግርኛ</source>
        <translation>ཐི་ཀོ་ལི་ནི་ཡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="150"/>
        <source>Türkmen</source>
        <translation>ཐུའུ་ཁུ་མན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="151"/>
        <source>Setswana</source>
        <translation>ཚེ་ཝ་ནའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="152"/>
        <source>Türkçe</source>
        <translation>ཐུར་ཁེའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="153"/>
        <source>Xitsonga</source>
        <translation>ཙོང་ཀའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="154"/>
        <source>Татарский</source>
        <translation>རྡ་རྡའི་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="155"/>
        <source>ئۇيغۇرچە</source>
        <translation>ཡུ་གུར་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="156"/>
        <source>Українська</source>
        <translation>ཝུའུ་ཁོ་ལན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="157"/>
        <source>اردو</source>
        <translation>ཝ་རྟུ་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="158"/>
        <source>Oʻzbekcha</source>
        <translation>ཝུའུ་ཙི་པེ་ཁེ་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="159"/>
        <source>Uzbek (Cyrillic)</source>
        <translation>ཝུའུ་ཙི་པེ་ཁེ་སྐད། (ཞི་ལིར་ཡིག)</translation>
    </message>
    <message>
        <location filename="language.h" line="160"/>
        <source>Venda</source>
        <translation>ཝེན་ཏ་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="161"/>
        <source>Tiếng Việt</source>
        <translation>ཝེ་ཐེ་ནམ་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="162"/>
        <source>Walon</source>
        <translation>ཝ་ལོན་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="163"/>
        <source>Wolof</source>
        <translation>ཝོ་ལོ་ཧྥུ་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="164"/>
        <source>isixhosa</source>
        <translation>ཁོ་ས་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="165"/>
        <source>ייִדיש</source>
        <translation>དབྱི་ཏི་ཀྲུ་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="166"/>
        <source>Yorùbá</source>
        <translation>ཡོ་རུ་པ་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="167"/>
        <source>简体中文</source>
        <translation>ཟོར་ཡང་རྒྱ་ཡིག</translation>
    </message>
    <message>
        <location filename="language.h" line="168"/>
        <source>繁體中文(香港)</source>
        <translation>ཟོར་ལྕིའི་རྒྱ་ཡིག(ཤང་ཀང་།)</translation>
    </message>
    <message>
        <location filename="language.h" line="169"/>
        <source>正體中文</source>
        <translation>གཟབ་ཅན་རྒྱ་ཡིག</translation>
    </message>
    <message>
        <location filename="language.h" line="170"/>
        <source>isiZulu</source>
        <translation>ཛུ་ལུ་སྐད།</translation>
    </message>
</context>
</TS>